Module Name:    src
Committed By:   skrll
Date:           Mon Jan  1 11:28:33 UTC 2018

Modified Files:
        src/sys/arch/evbarm/rpi: rpi_start.S

Log Message:
Need to map 512MB for some RPIs


To generate a diff of this commit:
cvs rdiff -u -r1.15 -r1.16 src/sys/arch/evbarm/rpi/rpi_start.S

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/evbarm/rpi/rpi_start.S
diff -u src/sys/arch/evbarm/rpi/rpi_start.S:1.15 src/sys/arch/evbarm/rpi/rpi_start.S:1.16
--- src/sys/arch/evbarm/rpi/rpi_start.S:1.15	Sun Dec 10 21:38:27 2017
+++ src/sys/arch/evbarm/rpi/rpi_start.S	Mon Jan  1 11:28:33 2018
@@ -1,4 +1,4 @@
-/*	$NetBSD: rpi_start.S,v 1.15 2017/12/10 21:38:27 skrll Exp $	*/
+/*	$NetBSD: rpi_start.S,v 1.16 2018/01/01 11:28:33 skrll Exp $	*/
 
 /*
  * Copyright (c) 2002, 2003  Genetec Corporation.  All rights reserved.
@@ -95,7 +95,7 @@
 #include <arm/armreg.h>
 #include "assym.h"
 
-RCSID("$NetBSD: rpi_start.S,v 1.15 2017/12/10 21:38:27 skrll Exp $")
+RCSID("$NetBSD: rpi_start.S,v 1.16 2018/01/01 11:28:33 skrll Exp $")
 
 
 #if defined(VERBOSE_INIT_ARM)
@@ -353,10 +353,10 @@ Lctl_ID_dis:
 
 mmu_init_table:
 	/*
 	 * Map 256MB of VA==PA at 0x00000000 so we can keep the kernel going
 	 * and get access to the FDT the firmware loads
 	 */
-	MMU_INIT(0x0, 0x0, 0x10000000, L1_S_PROTO | L1_S_APv6_KRW)
+	MMU_INIT(0x0, 0x0, (512 * 1024 * 1204), L1_S_PROTO | L1_S_APv6_KRW)
 
 	MMU_INIT(KERNEL_BASE, 0x0,
 	    (_end - KERNEL_BASE + 2 * L1_S_SIZE - 1),
@@ -353,10 +353,10 @@ Lctl_ID_dis:
 mmu_init_table:
 	/*
-	 * Map 256MB of VA==PA at 0x00000000 so we can keep the kernel going
+	 * Map 512MB of VA==PA at 0x00000000 so we can keep the kernel going
 	 * and get access to the FDT the firmware loads
 	 */

Reply via email to